@@ -44,13 +44,13 @@ impl Client {
     /// ```no_run
     /// # extern crate tokio; use anyhow::Result;
     /// # use safe_network::client::utils::test_utils::read_network_conn_info;
-    /// use safe_network::client::Client;
+    /// use safe_network::client::{Client, DEFAULT_QUERY_TIMEOUT};
     /// use safe_network::types::ChunkAddress;
     /// use xor_name::XorName;
     /// # #[tokio::main] async fn main() { let _: Result<()> = futures::executor::block_on( async {
     /// let head_chunk = ChunkAddress::Public(XorName::random());
     /// # let bootstrap_contacts = Some(read_network_conn_info()?);
-    /// let client = Client::new(None, None, bootstrap_contacts).await?;
+    /// let client = Client::new(None, None, bootstrap_contacts, DEFAULT_QUERY_TIMEOUT).await?;
     ///
     /// // grab the random head of the blob from the network
     /// let _data = client.read_blob(head_chunk, None, None).await?;
@@ -96,13 +96,13 @@ impl Client {
     /// ```no_run
     /// # extern crate tokio; use anyhow::Result;
     /// # use safe_network::client::utils::test_utils::read_network_conn_info;
-    /// use safe_network::client::Client;
+    /// use safe_network::client::{Client, DEFAULT_QUERY_TIMEOUT};
     /// use safe_network::types::Token;
     /// use std::str::FromStr;
     /// # #[tokio::main] async fn main() { let _: Result<()> = futures::executor::block_on( async {
     /// // Let's use an existing client, with a pre-existing balance to be used for write payments.
     /// # let bootstrap_contacts = Some(read_network_conn_info()?);
-    /// let mut client = Client::new(None, None, bootstrap_contacts).await?;
+    /// let mut client = Client::new(None, None, bootstrap_contacts, DEFAULT_QUERY_TIMEOUT).await?;
     /// # let initial_balance = Token::from_str("100")?; client.trigger_simulated_farming_payout(initial_balance).await?;
     /// let data = b"some data".to_vec();
     /// // grab the random head of the blob from the network
@@ -127,13 +127,13 @@ impl Client {
     /// ```no_run
     /// # extern crate tokio; use anyhow::Result;
     /// # use safe_network::client::utils::test_utils::read_network_conn_info;
-    /// use safe_network::client::Client;
+    /// use safe_network::client::{Client, DEFAULT_QUERY_TIMEOUT};
     /// use safe_network::types::Token;
     /// use std::str::FromStr;
     /// # #[tokio::main] async fn main() { let _: Result<()> = futures::executor::block_on( async {
     /// // Let's use an existing client, with a pre-existing balance to be used for write payments.
     /// # let bootstrap_contacts = Some(read_network_conn_info()?);
-    /// let mut client = Client::new(None, None, bootstrap_contacts).await?;
+    /// let mut client = Client::new(None, None, bootstrap_contacts, DEFAULT_QUERY_TIMEOUT).await?;
     /// # let initial_balance = Token::from_str("100")?; client.trigger_simulated_farming_payout(initial_balance).await?;
     /// let data = b"some data".to_vec();
     /// // grab the random head of the blob from the network
@@ -205,14 +205,14 @@ impl Client {
     ///
     /// ```no_run
     /// # use safe_network::client::utils::test_utils::read_network_conn_info;
-    /// use safe_network::client::Client;
+    /// use safe_network::client::{Client, DEFAULT_QUERY_TIMEOUT};
     /// use safe_network::types::Token;
     /// use std::str::FromStr;
     /// # #[tokio::main] async fn main() { let _: anyhow::Result<()> = futures::executor::block_on( async {
     ///
     /// // Let's use an existing client, with a pre-existing balance to be used for write payments.
     /// # let bootstrap_contacts = Some(read_network_conn_info()?);
-    /// let mut client = Client::new(None, None, bootstrap_contacts).await?;
+    /// let mut client = Client::new(None, None, bootstrap_contacts, DEFAULT_QUERY_TIMEOUT).await?;
     /// # let initial_balance = Token::from_str("100")?; client.trigger_simulated_farming_payout(initial_balance).await?;
     /// let data = b"some private data".to_vec();
     /// let address = client.store_private_blob(&data).await?;
@@ -403,13 +403,13 @@ mod tests {
     use super::{Chunk, ChunkAddress, Client, DataMap, DataMapLevel, Error};
     use crate::client::client_api::blob_storage::BlobStorage;
     use crate::client::utils::{generate_random_vector, test_utils::create_test_client};
-    use crate::messaging::client::Error as ErrorMessage;
     use crate::types::{PrivateChunk, PublicChunk, Token};
     use crate::{retry_err_loop, retry_loop};
     use anyhow::{anyhow, bail, Result};
     use bincode::deserialize;
     use self_encryption::Storage;
     use std::str::FromStr;
+    use tokio::time::Duration;
 
     // Test storing and getting public Blob.
     #[tokio::test]
@@ -421,10 +421,7 @@ mod tests {
         // Get non-existent Blob
         match client.read_blob(expected_address, None, None).await {
             Ok(data) => bail!("public chunk should not exist yet: {:?}", data),
-            Err(Error::ErrorMessage {
-                source: ErrorMessage::DataNotFound(_),
-                ..
-            }) => (),
+            Err(Error::NoResponse) => (),
             Err(e) => bail!("Unexpected: {:?}", e),
         }
 
@@ -448,7 +445,7 @@ mod tests {
     // Test storing, getting, and deleting private chunk.
     #[tokio::test]
     pub async fn private_blob_test() -> Result<()> {
-        let client = create_test_client().await?;
+        let mut client = create_test_client().await?;
 
         let value = generate_random_vector::<u8>(10);
 
@@ -458,11 +455,8 @@ mod tests {
         // Get non-existent Blob
         match client.read_blob(expected_address, None, None).await {
             Ok(_) => bail!("private chunk should not exist yet"),
-            Err(Error::ErrorMessage {
-                source: ErrorMessage::DataNotFound(_),
-                ..
-            }) => (),
-            Err(e) => bail!("Expecting DataNotFound error, got: {:?}", e),
+            Err(Error::NoResponse) => (),
+            Err(e) => bail!("Expecting NoResponse error, got: {:?}", e),
         }
 
         // Store Blob
@@ -491,6 +485,8 @@ mod tests {
 
         // Make sure Blob was deleted
         let mut attempts = 10u8;
+        let orignal_timeout = client.query_timeout;
+        client.query_timeout = Duration::from_secs(5); // override with a short timeout
         while client.read_blob(priv_address, None, None).await.is_ok() {
             tokio::time::sleep(tokio::time::Duration::from_millis(4000)).await;
             if attempts == 0 {
@@ -500,6 +496,8 @@ mod tests {
             }
         }
 
+        client.query_timeout = orignal_timeout; // reset override
+
         // Test storing private chunk with the same value again. Should not conflict.
         let new_addr = client.store_private_blob(&value).await?;
         assert_eq!(new_addr, priv_address);
@@ -513,7 +511,7 @@ mod tests {
 
     #[tokio::test]
     pub async fn private_delete_large() -> Result<()> {
-        let client = create_test_client().await?;
+        let mut client = create_test_client().await?;
 
         let value = generate_random_vector::<u8>(1024 * 1024);
         let address = client.store_private_blob(&value).await?;
@@ -533,6 +531,7 @@ mod tests {
 
         client.delete_blob(address).await?;
 
+        client.query_timeout = Duration::from_secs(5); // override with a short timeout
         let mut blob_storage = BlobStorage::new(client, false);
 
         if let DataMap::Chunks(chunks) = root_data_map {
@@ -716,10 +715,7 @@ mod tests {
         // attempt to retrieve it with generated address (it should error)
         let res = client.read_blob(*address_before, None, None).await;
         match res {
-            Err(Error::ErrorMessage {
-                source: ErrorMessage::DataNotFound(_),
-                ..
-            }) => (),
+            Err(Error::NoResponse) => (),
             Ok(_) => bail!("Blob unexpectedly retrieved using address generated by gen_data_map"),
             Err(_) => bail!(
                 "Unexpected error when Blob retrieved using address generated by gen_data_map"
